@@ -7,7 +7,11 @@ from enum import Enum
 from sqlalchemy.sql import FromClause
 from sqlalchemy.sql.elements import BooleanClauseList
 
-from bakplane.bakplane_pb2 import Universe, ResolveResourceIntentResponse, ResolveResourcePathResponse
+from bakplane.bakplane_pb2 import (
+    Universe,
+    ResolveResourceIntentResponse,
+    ResolveResourcePathResponse,
+)
 
 from sqlalchemy import Table, Column
 
@@ -61,16 +65,23 @@ class ReadRequestBuildingBlocks:
 
 class DataStoreHelper(ABC):
     @abstractmethod
-    def create_temporary_table(self, prefix: str, columns: typing.List[Column],
-                               rows: typing.List[typing.Any]) -> Table:
+    def create_temporary_table(
+        self,
+        prefix: str,
+        columns: typing.List[Column],
+        rows: typing.List[typing.Any],
+    ) -> Table:
         pass
 
 
 class Modifier:
     @abstractmethod
-    def execute(self, r: ReadRequestBuildingBlocks, h: DataStoreHelper) -> ReadRequestBuildingBlocks:
+    def execute(
+        self, r: ReadRequestBuildingBlocks, h: DataStoreHelper
+    ) -> ReadRequestBuildingBlocks:
         pass
 
+
 @dataclass
 class ReadRequest:
     path: str
@@ -82,9 +93,15 @@ class ReadRequest:
     columns: typing.List[str] = None
     knowledge_start_dt: datetime.datetime = None
     knowledge_end_dt: datetime.datetime = None
-    query_builder: typing.Callable[[ReadRequestBuildingBlocks], typing.Any] = None
-    additional_constraints: typing.Callable[[ReadRequestBuildingBlocks], BooleanClauseList] = None
-    effective_dating_hint: typing.Union[str, typing.Tuple[datetime.datetime, datetime.datetime]] = None
+    query_builder: typing.Callable[
+        [ReadRequestBuildingBlocks], typing.Any
+    ] = None
+    additional_constraints: typing.Callable[
+        [ReadRequestBuildingBlocks], BooleanClauseList
+    ] = None
+    effective_dating_hint: typing.Union[
+        str, typing.Tuple[datetime.datetime, datetime.datetime]
+    ] = None
     modifiers: typing.List[Modifier] = None
 
 
@@ -121,9 +138,15 @@ class PluginEntry:
     code: str
     description: str
     author: str
-    write_fn: typing.Callable[[WriteRequest, ResolveResourcePathResponse], WriteResponse]
-    read_fn: typing.Callable[[typing.Any, ReadRequest, ResolveResourceIntentResponse], ReadResponse]
-    read_all_fn: typing.Callable[[typing.Any, ReadAllRequest, ResolveResourcePathResponse], ReadResponse]
+    write_fn: typing.Callable[
+        [WriteRequest, ResolveResourcePathResponse], WriteResponse
+    ]
+    read_fn: typing.Callable[
+        [typing.Any, ReadRequest, ResolveResourceIntentResponse], ReadResponse
+    ]
+    read_all_fn: typing.Callable[
+        [typing.Any, ReadAllRequest, ResolveResourcePathResponse], ReadResponse
+    ]
     connection_string_url_fn: typing.Callable[[ConnectionStringContext], str]
     driver_name: str
 
